@@ -80,7 +80,7 @@ class FlairClient:
             return None
 
     async def get_users(self) -> Users:
-        """Get all users information."""
+        """Get all users' information."""
 
         fetched_users = await self._get(f'{Endpoint.USERS_URL}')
         users: dict[str, User] = {}
@@ -408,14 +408,14 @@ class FlairClient:
         return FlairData(users=users_data, structures=structures_data )
 
 
-    async def get_related(self, object, type: str) -> list[int]:
+    async def get_related(self, flair_object, related_type: str) -> list[int]:
         """Get vents, rooms, pucks, etc. related to the object."""
 
-        link = object.relationships[type]['links']['related']
+        link = flair_object.relationships[related_type]['links']['related']
         response = await self._get(link)
         return response['data']
 
-    async def fetch_all_structure_relations(self, object: Structure) -> list:
+    async def fetch_all_structure_relations(self, flair_object: Structure) -> list:
         """
         Parallel request are made to all related endpoints for a single structure.
         Returns a list containing rooms, pucks, vents, thermostats, HVAC units, and Zones
@@ -423,13 +423,13 @@ class FlairClient:
         """
 
         results = await asyncio.gather(*[
-            self.get_related(object, 'rooms'),
-            self.get_related(object, 'pucks'),
-            self.get_related(object, 'vents'),
-            self.get_related(object, 'thermostats'),
-            self.get_related(object, 'hvac-units'),
-            self.get_related(object, 'zones'),
-            self.get_related(object, 'schedules')
+            self.get_related(flair_object, 'rooms'),
+            self.get_related(flair_object, 'pucks'),
+            self.get_related(flair_object, 'vents'),
+            self.get_related(flair_object, 'thermostats'),
+            self.get_related(flair_object, 'hvac-units'),
+            self.get_related(flair_object, 'zones'),
+            self.get_related(flair_object, 'schedules')
             ],
         )
         return results
@@ -453,13 +453,13 @@ class FlairClient:
         request_url = f'/api/{resource_type}'
         return await self._post(request_url, headers, request_data)
 
-    async def delete(self, resource_type: str, id: str) -> None:
+    async def delete(self, resource_type: str, item_id: str) -> None:
         """Delete a Flair room. Other scenarios currently untested."""
 
-        request_url = f'/api/{resource_type}/{id}'
+        request_url = f'/api/{resource_type}/{item_id}'
         return await self._delete(request_url)
 
-    async def update(self, resource_type: str, id: str, attributes: dict[str, Any], relationships: dict[str, Any]) -> dict[str, Any]:
+    async def update(self, resource_type: str, item_id: str, attributes: dict[str, Any], relationships: dict[str, Any]) -> dict[str, Any]:
         """Set structure mode, structure system mode, vent % open, select schedule, etc."""
 
         request_data = {
@@ -469,7 +469,7 @@ class FlairClient:
                 "relationships": relationships
             }
         }
-        request_url = f'/api/{resource_type}/{id}'
+        request_url = f'/api/{resource_type}/{item_id}'
         return await self._patch(request_url, request_data)
 
     async def _create_get_header(self) -> dict[str, str]:
@@ -505,9 +505,10 @@ class FlairClient:
                     data=data, timeout=self.timeout) as resp:
                 return await self._response(resp)
 
-    async def _get(self, endpoint: str, data: dict[str, Any] = {}) -> dict[str, Any]:
+    async def _get(self, endpoint: str, data: dict[str, Any] = None) -> dict[str, Any]:
         """Make GET call to Flair servers."""
 
+        data = data if data else {}
         await self.check_token()
         headers = await self._create_get_header()
         async with self._session.get(
